# mmWave Package

[![Version](https://img.shields.io/pypi/v/ipyvolume.svg)](https://pypi.org/project/mmWave/)

This is a mmWave data parsing library package work with Joybien mmWave EVM Kit.

## libray include:
1. vitalsign v0.0.10
2.  highAccuraccy v0.0.4
3. peopleMB v0.0.4
4. srradar v0.0.1
5. people3D v0.0.2
6. pc3d v0.0.3
7. pc3d_kv v0.0.2
8. lpdISK v0.0.1
          v0.0.2 2023/02/03 lpdISK firmware: 0910 and 0985 (added EC16,g,confi)
          v0.0.3 2023/02/04 combine: v0.0.1 & v0.0.2
9.  lpdISK_kv v0.0.1
10. vehicleOD v0.0.1   (deprecated)
11. trafficMD_kv v0.0.2
12. surfaceVD v0.0.1
13. trafficMD v0.1.0    update:2021/04/21
14. droneRN v0.0.2
15. pc3 v0.1.4          update:2021/10/12(doppler & range swap: seq:eadrs)
16. vehicleODHeatMap v0.0.1
17. vitalsign_kv v0.0.1
18. vehicleODR v0.0.1  (VOD: Vehicle Occupancy Detection)
19. roadwayTMD_kv v0.1.2 update:2021/05/04 (TRS: Traffic monitoring detection Roadway Sensing )
20. pc3OVH v0.1.2    2021/08/12(OVH: OVerHead) 
           v1.0.0    2022/07/18 pc3OVH add tilt, install height and (sx,sy,sz) in raw data mode
           v1.0.1    2022/07/19 pc3OVH add added v6 fetch time
           v1.0.2    2022/07/20 raw data: (elv,azi,ran,dop,snr,sx,sy,sz)..
           v1.0.3    2023/11/01 pc3OVH    v6 tilt revised
21. lpdFDS  v0.1.2    updated:2021/05/26 (FDS: Falling Detection Sensing) 
22. trafficMD_I480 v0.1.0   2021/09/16 (Traffic Monitoring Detection version:I480)
            v0.1.1 2022/03/10 bug fix
            v2.0.1 2022/04/28 (output data posZ,velZ,accZ position change)
            v2.0.2/3 added tlvRead status, chk: {0:'EMPTY',1:'inData',10:'IDLE',99:'FALSE'}
            v2.0.4 added tlvRead status, chk: {0:'EMPTY',1:'inData',10:'IDLE',99:'FALSE'}
            v2.0.5 2023/02/10 correct v7 'tid' text position
            
23. mrRadar v0.0.1 2021/12/31 released (MRR: Medium Range Radar)
            v0.0.2 2022/02/07 format revised
            v0.1.0 2022/06/02 fit v3 data
            v1.0.0 2022/06/08 change data get method
            v1.0.1 :2022/06/09 added headerShowAll()
24. pc3_oob v0.0.1 2022/03/01 first released
            v0.0.2 2022/03/01 bug fix
            v0.0.3 2022/03/03
            v0.0.4 :2023/05/25 @v1.0.97 add v7, playback
            v0.0.5 :2023/05/25 @v1.0.98 fix dataframe 
            
25. pc3_vsd v0.0.1 2022/03/10 Bata version (deprecated)
26. pc3_v2  v2     2022/04/19 first released
            v2.0.1 2022/06/10 pc3_v2 v6 add sx,sy,sz   
            v2.0.2 2022/06/13 pc3_v2 add azimuth offset 
            
27. pc3_360 v0.0.1 2022/08/16 for integrate 3 sets of module. 

28. pc3_vsd_v2 v0.0.1 2022/09/12 Bata version.

29. lpdISK_v2 v0.0.1 2022/11/03 for firmware:v4.12.0 (Beta version)

30. pct     v2.0.0 2023/02/08 People Counting 3D with Tilt 
            v2.0.1 2023/02/09 modified dataframe type for playback
            
31. obstacleDS v0.0.1 2023/07/05 obstacle Detection sensor

32. pc3_v1884R v0.0.3 : 2023/07/12 add recording_v2, readFile_v2 ,getRecordData_v2
               v0.0.4 : 2024/03/13 pc3_V1884R fix unpack requires a buffer of 8 bytes

33. pc3_fish v1 : 2023/8/11 v6:readsxyz use:recording_v2, readFile_v2 ,getRecordData_v2
     
34. pc3_fish v1.0.1 : 2023/8/14 v6:xyzreadsf and modified:recording_v2, readFile_v2
				      added fn and timeTag items in recording_v2 function

## Example code 
- Example code you can down load from [GitHub](https://github.com/bigheadG/mmWave) if you found any bugs or have any suggestions Please submit issues to Github

## installation
```
pip3 install mmWave
```

## update history
1. 2021/09/16 pc3OVH v0.1.2 : @v7 dataFrame colume change. 'tid' move to front of 'ec0'
2. 2021/10/12 pc3    v0.1.4   update:(doppler & range swap: seq:eadrs)
3. mmWave-0.1.62
   2021/12/31 MRR    v0.0.1   added MRR
4. mmWave-0.1.63
   2022/02/07 MRR    v0.0.2   update(format revised)
5. mmWave-0.1.64
   2022/03/01 pc3_oob v0.0.1  added pc3_oob
5. mmWave-0.1.65
   2022/03/01 pc3_oob v0.0.2  bug fix
   2022/03/03 pc3_oob v0.0.3  bug fix
6. mmWave-1.0.68   
   2022/03/10 pc3_vsd v0.0.1  beta version 
   
7. mmWave-1.0.70   
   2022/04/19 pc3_v2 v2.0 @copy from pc3OVH

8. mmWave-1.0.71   
   2022/04/28 trafficMD_I480 v2.0.1 (output data posZ,velZ,accZ position change)
9. mmWave-1.0.72 (remove)
10. mmWave-1.0.73  
   2022/05/12 trafficMD_I480 v2.0.2 "added tlvRead status, chk: {0:'EMPTY',1:'inData',10:'IDLE',99:'FALSE'}
11. mmWave-1.0.74  
    2022/05/15 trafficMD_I480 v2.0.4 revised v8,v9 as dictionay data type
12. mmWave-1.0.75  
    2022/06/02 mrRadar revised to fit v3 
13. mmWave-1.0.76  
    2022/06/08 mrRadar revised data get method
14. mmWave-1.0.77      
    2022/06/09 mrRadar added headerShowAll()
15. mmWave-1.0.78
    2022/06/10 pc3_v2 v2.0.1, (v6 data update) add sx,sy,sz
    2022/06/13 pc3_v2 v2.0.2, added azimuth offset 
16. mmWave-1.0.79
    2022/06/13 pc3_v2 v2.0.2, added azimuth offset 
    2023/06/30 pc3_v2 v2.0.3, playback function
17. mmWave-1.0.80
    2022/07/18 pc3OVH v1.0.0, added tilt,install height and (sx,sy,sz) in raw data mode     
18. mmWave-1.0.81 
    2022/07/19 pc3OVH v1.0.1, added v6 fetch time
19. mmWave-1.0.83 (fix 82)
    2022/07/20 v1.0.2 raw data: (elv,azi,ran,dop,snr,sx,sy,sz)..
20. mmWave-1.0.84 
    2022/08/16 pc3_360 v1.0.1, added for integrate 3 sets of radar module to 360° FOV (first release)
21. mmWave-1.0.85/86 
    2022/09/12 pc3_vsd_v2 v0.0.1, Bata version.
22. mmWave-1.0.85/87 
    2022/09/15 pc3_vsd_v2 v0.0.1,  Bata version swap dictionary: br & hr
23. mmWave-1.0.88 
    2022/11/03 lpdISK_v2 v0.0.1,  Bata version, firmware:v4.12.0
24. mmWave-1.0.89
    2022/01/05 pc3_V1884R v0.0.1, firmware: V1884R
25. mmWave-1.0.90
    2023/02/03 lpdISK v0.0.2 firmware: 0910 and 0985
26. mmWave-1.0.91
    2023/02/04 lpdISK v0.0.2 firmware: combine v7 struct v0.0.1 and v0.0.2
27. mmWave-1.0.92
    2023/02/08  pct v2.0.0, People Counting 3D with Tilt firmware: v4958
    2023/02/09  pct v2.0.1, modified dataframe type for playback
    
28. mmWave-1.0.93
    2023/02/10 trafficMD_I480 v2.0.4, revised v7 'tid' text position

29. mmWave-1.0.95
    2023/03/24 mrRadar   v1.0.2  header enable/disable in inital
    2023/03/24 trafficMD v0.1.1  header enable/disable in inital
    2023/03/24  trafficMD_I480   ver:2.0.6 header enable/disable in inital
30. mmWave-1.0.96
    2023/04/07 pc3_V1884R v0.0.2  add try..except in unpack
   
31. mmWave-1.0.97
    2023/05/25 pc3_oob v0.0.4 add v7, playback 
32. mmWave-1.0.98
    2023/05/25 pc3_oob v0.0.5 bug fix 
33. mmWave-1.0.100
    2023/07/05 obstacleDS v0.0.1

33. mmWave-1.0.101
    2023/07/12 pc3_V1884R v0.0.3 add recording_v2, readFile_v2 ,getRecordData_v2
    
34. mmWave-1.0.102
    2023/08/11 pc3_fish v1 : v6:readsxyz use:recording_v2, readFile_v2 ,getRecordData_v2
    
35. mmWave-1.0.103
    2023/08/14 pc3_fish v1.0.1 : v6:xyzreadsf and modified:recording_v2, readFile_v2
							 added fn and timeTag items in recording_v2 function
36. mmWave-1.0.104
	2023/11/01 pc3OVH   v1.0.3 : v6 tilt revised

37. mmWave-1.0.105
    2024/03/13 pc3_V1884R v0.0.4 fixed unpack requires a buffer of 8 bytes(beta)
    
38. mmWave-1.0.106
    2025/02/13 pc3_360 v1.0.2 add zOffset for z axis
